@@ -4,7 +4,7 @@ from __future__ import absolute_import, unicode_literals
 
 
 CLICK_TOOLBELT_PROJECT_NAME = 'click-toolbelt'
-CLICK_UPDOWN_UPLOAD_URL = 'https://upload.apps.ubuntu.com/upload/'
+CLICK_UPDOWN_UPLOAD_URL = 'https://upload.apps.ubuntu.com/'
 MYAPPS_API_ROOT_URL = 'https://myapps.developer.ubuntu.com/dev/api/'
 UBUNTU_SSO_API_ROOT_URL = 'https://login.ubuntu.com/api/v2/'
 SCAN_STATUS_POLL_DELAY = 10
