@@ -224,6 +224,7 @@ class UploadAppTestCase(BaseUploadCommandTestCase):
         mock_response.json.return_value = {
             'success': True,
             'status_url': 'http://example.com/status/',
+            'web_status_url': 'http://example.com/status-web/',
         }
 
         mock_status_response = self.mock_get.return_value
@@ -237,7 +238,29 @@ class UploadAppTestCase(BaseUploadCommandTestCase):
             'errors': [
                 'Package scan took too long.',
                 'Please check the status later at: '
-                'http://example.com/status/.',
+                'http://example.com/status-web/.',
+            ],
+            'application_url': '',
+        })
+
+    def test_upload_app_abort_polling_without_web_status_url(self):
+        mock_response = self.mock_post.return_value
+        mock_response.ok = True
+        mock_response.json.return_value = {
+            'success': True,
+            'status_url': 'http://example.com/status/',
+        }
+
+        mock_status_response = self.mock_get.return_value
+        mock_status_response.ok = True
+        mock_status_response.json.return_value = {
+            'completed': False
+        }
+        response = self.command.upload_app(self.package_name, self.data)
+        self.assertEqual(response, {
+            'success': False,
+            'errors': [
+                'Package scan took too long.',
             ],
             'application_url': '',
         })
