@@ -95,7 +95,8 @@ class Upload(ClickToolbeltUploadCommand):
 
             response = session.post(upload_url, data=data, files=files)
             if response.ok:
-                status_url = response.json()['status_url']
+                response_data = response.json()
+                status_url = response_data['status_url']
                 self.log.info('Package submitted to %s', upload_url)
                 self.log.info('Checking package status...')
                 completed, data = self.get_scan_data(session, status_url)
@@ -109,8 +110,13 @@ class Upload(ClickToolbeltUploadCommand):
                 else:
                     result['errors'] = [
                         'Package scan took too long.',
-                        'Please check the status later at: %s.' % status_url,
                     ]
+                    status_web_url = response_data.get('web_status_url')
+                    if status_web_url:
+                        result['errors'].append(
+                            'Please check the status later at: %s.' % (
+                                status_web_url),
+                        )
                 result['application_url'] = data.get('application_url', '')
             else:
                 self.log.error(
